Autenticação Mecânica / Ficha de Compensação Código de baixa Sacador / Avalista Sacado Client Mainstreet 138, Cidade Araci 12345-678 - Los Angeles - Californa (=) Valor cobrado (+) Outros acréscimos (+) Mora/Multa (-) Outras deduções (-) Descontos/Abatimentos Instruções Primeia linha da instrução Stoq Retail Management - www.stoq.com.br Uso do banco Carteira Espécie Quantidade Valor (=) Valor documento 18 R$ 10,00 Data do documento N. do documento Espécie doc Aceite Data processamento Nosso número 30/05/2011 400 DM N 30/05/2011 12345678000000400-9 Cedente Agência/Código cedente Moda Stoq 1172-0 / 00403005-2 Local de pagamento Vencimento Pagável em qualquer banco até o vencimento 30/05/2011 001-9 00190.00009 01234.567806 00000.400184 1 49830000001000 001-9 Recibo do Sacado Autenticação Mecânica Cedente Agência/Código Cedente Data Documento Vencimento Endereço Cedente CNPJ Cedente Sacado Nosso Número N. do documento Valor Documento Demonstrativo Moda Stoq 1172-0 / 00403005-2 30/05/2011 30/05/2011 Avendia São Carlos 2333, Centro, 13560-001 - São Carlos - SP 24.198.774/7322-35 Client 12345678000000400-9 400 10,00 sale XXX XXX - description